@@ -34,6 +34,8 @@ const GLib = imports.gi.GLib;
 
 const Main = imports.main;
 const Format = imports.format;
+const Geoclue = imports.geoclue;
+const GeocodeService = imports.geocodeService;
 const MainWindow = imports.mainWindow;
 const Notification = imports.notification;
 const NotificationManager = imports.notificationManager;
@@ -41,12 +43,16 @@ const Utils = imports.utils;
 const Path = imports.path;
 const Settings = imports.settings;
 const PlaceStore = imports.placeStore;
+const RouteService = imports.routeService;
 
 // used globally
 let application = null;
 let settings = null;
 let placeStore = null;
 let notificationManager = null;
+let routeService = null;
+let geoclue = null;
+let geocodeService = null;
 
 const Application = new Lang.Class({
     Name: 'Application',
@@ -93,7 +99,7 @@ const Application = new Lang.Class({
         Utils.loadStyleSheet(Gio.file_new_for_uri('resource:///org/gnome/maps/application.css'));
 
         application = this;
-        settings = new Settings.Settings('org.gnome.maps');
+        this._initServices();
 
         Utils.initActions(this, [{
             properties: { name: 'quit' },
@@ -104,6 +110,13 @@ const Application = new Lang.Class({
         this._initAppMenu();
     },
 
+    _initServices: function() {
+        settings       = new Settings.Settings('org.gnome.maps');
+        routeService   = new RouteService.GraphHopper();
+        geoclue        = new Geoclue.Geoclue();
+        geocodeService = new GeocodeService.GeocodeService();
+    },
+
     _createWindow: function() {
         if (this._mainWindow)
             return;
