@@ -34,12 +34,10 @@ const Mainloop = imports.mainloop;
 const Signals = imports.signals;
 
 const Application = imports.application;
-const Sidebar = imports.sidebar;
 const Utils = imports.utils;
 const Path = imports.path;
 const MapLocation = imports.mapLocation;
 const UserLocation = imports.userLocation;
-const Geoclue = imports.geoclue;
 const _ = imports.gettext.gettext;
 
 const MapType = {
@@ -58,19 +56,41 @@ const MapView = new Lang.Class({
     _init: function() {
         this.parent();
 
-        this.actor = this.get_view();
-        this.view = this.actor;
-        this.view.set_zoom_level(3);
-        this.view.min_zoom_level = MapMinZoom;
-        this.view.goto_animation_mode = Clutter.AnimationMode.EASE_IN_OUT_CUBIC;
-        this.view.set_reactive(true);
+        this.view = this._initView();
+        this._initLayers();
 
-        this.view.connect('notify::latitude', this._onViewMoved.bind(this));
-        this.view.connect('notify::longitude', this._onViewMoved.bind(this));
+        this._factory = Champlain.MapSourceFactory.dup_default();
+        this.setMapType(MapType.STREET);
 
-        this._sidebar = new Sidebar.Sidebar(this);
-        // Don't show sidebar until it has something in it
-        //this.view.add_child(this._sidebar.actor);
+        this._updateUserLocation();
+        Application.geoclue.connect("location-changed",
+                                    this._updateUserLocation.bind(this));
+
+        this._connectRouteSignals(Application.routeService.route);
+    },
+
+    _initView: function() {
+        let view = this.get_view();
+        view.set_zoom_level(3);
+        view.min_zoom_level = MapMinZoom;
+        view.goto_animation_mode = Clutter.AnimationMode.EASE_IN_OUT_CUBIC;
+        view.set_reactive(true);
+
+        view.connect('notify::latitude', this._onViewMoved.bind(this));
+        view.connect('notify::longitude', this._onViewMoved.bind(this));
+        // switching map type will set view min-zoom-level from map source
+        view.connect('notify::min-zoom-level', (function() {
+            if (view.min_zoom_level < MapMinZoom) {
+                view.min_zoom_level = MapMinZoom;
+            }
+        }).bind(this));
+        return view;
+    },
+
+    _initLayers: function() {
+        this._routeLayer = new Champlain.PathLayer();
+        this._routeLayer.set_stroke_width(2.0);
+        this.view.add_layer(this._routeLayer);
 
         this._markerLayer = new Champlain.MarkerLayer();
         this._markerLayer.set_selection_mode(Champlain.SelectionMode.SINGLE);
@@ -79,22 +99,11 @@ const MapView = new Lang.Class({
         this._userLocationLayer = new Champlain.MarkerLayer();
         this._userLocationLayer.set_selection_mode(Champlain.SelectionMode.SINGLE);
         this.view.add_layer(this._userLocationLayer);
+    },
 
-        // switching map type will set view min-zoom-level from map source
-        this.view.connect('notify::min-zoom-level', (function() {
-            if (this.view.min_zoom_level < MapMinZoom) {
-                this.view.min_zoom_level = MapMinZoom;
-            }
-        }).bind(this));
-
-        this._factory = Champlain.MapSourceFactory.dup_default();
-        this.setMapType(MapType.STREET);
-
-
-        this.geoclue = new Geoclue.Geoclue();
-        this._updateUserLocation();
-        this.geoclue.connect("location-changed",
-                             this._updateUserLocation.bind(this));
+    _connectRouteSignals: function(route) {
+        route.connect('update', this.showRoute.bind(this, route));
+        route.connect('reset', this._routeLayer.remove_all.bind(this._routeLayer));
     },
 
     setMapType: function(mapType) {
@@ -105,30 +114,6 @@ const MapView = new Lang.Class({
         this.view.set_map_source(source);
     },
 
-    geocodeSearch: function(searchString, searchCompleteCallback) {
-        let forward = Geocode.Forward.new_for_string(searchString);
-        let places = [];
-        let answerCount = Application.settings.get('max-search-results');
-        let bbox = this.view.get_bounding_box();
-
-        forward.search_area = new Geocode.BoundingBox({
-            top: bbox.top,
-            left: bbox.left,
-            bottom: bbox.bottom,
-            right: bbox.right
-        });
-        forward.bounded = false;
-        forward.set_answer_count(answerCount);
-        forward.search_async (null, (function(forward, res) {
-            try {
-                places = forward.search_finish(res);
-            } catch (e) {
-                places = null;
-            }
-            searchCompleteCallback(places);
-        }).bind(this));
-    },
-
     ensureLocationsVisible: function(locations) {
         let bbox = new Champlain.BoundingBox({ left:   180,
                                                right: -180,
@@ -159,12 +144,14 @@ const MapView = new Lang.Class({
     },
 
     _updateUserLocation: function() {
-        if (!this.geoclue.location)
+        let location = Application.geoclue.location;
+
+        if (!location)
             return;
 
-        let place = Geocode.Place.new_with_location(this.geoclue.location.description,
+        let place = Geocode.Place.new_with_location(location.description,
                                                     Geocode.PlaceType.UNKNOWN,
-                                                    this.geoclue.location);
+                                                    location);
 
         let selected = this._userLocation && this._userLocation.getSelected();
         this._userLocation = new UserLocation.UserLocation(place, this);
@@ -187,6 +174,28 @@ const MapView = new Lang.Class({
         mapLocation.goTo(true);
     },
 
+    showRoute: function(route) {
+        this._routeLayer.remove_all();
+
+        route.path.forEach(this._routeLayer.add_node.bind(this._routeLayer));
+
+        // Animate to the center of the route bounding box
+        // goto() is currently implemented on mapLocation, so we need to go
+        // through some hoops here.
+        let [lat, lon] = route.bbox.get_center();
+        let place = new Geocode.Place({
+            location     : new Geocode.Location({ latitude  : lat,
+                                                  longitude : lon }),
+            bounding_box : new Geocode.BoundingBox({ top    : route.bbox.top,
+                                                     bottom : route.bbox.bottom,
+                                                     left   : route.bbox.left,
+                                                     right  : route.bbox.right })
+        });
+        let mapLocation = new MapLocation.MapLocation(place, this);
+
+        mapLocation.goTo(true);
+    },
+
     _onViewMoved: function() {
         this.emit('view-moved');
     }
